==> gallery-dl-1.30.8.gh.tar.gz: gallery-dl-1.30.8/test/results/thehentaiworld.py <==
# -*- coding: utf-8 -*-

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.

from gallery_dl.extractor import thehentaiworld


__tests__ = (
{
    "#url"     : "https://thehentaiworld.com/hentai-images/samus-aran-aurahack-metroid-2/",
    "#class"   : thehentaiworld.ThehentaiworldPostExtractor,
    "#results" : "https://thehentaiworld.com/wp-content/uploads/2020/06/Samus-Aran-Aurahack-Metroid-Hentai.jpeg",

    "count"         : 1,
    "num"           : 0,
    "date"          : "dt:2020-06-05 00:00:00",
    "extension"     : "jpeg",
    "file_url"      : "https://thehentaiworld.com/wp-content/uploads/2020/06/Samus-Aran-Aurahack-Metroid-Hentai.jpeg",
    "filename"      : "Samus-Aran-Aurahack-Metroid-Hentai",
    "height"        : 2893,
    "id"            : 147048,
    "score"         : range(3, 5),
    "slug"          : "samus-aran-aurahack-metroid-2",
    "title"         : "Samus Aran – Aurahack – Metroid",
    "type"          : "image",
    "votes"         : range(5, 20),
    "width"         : 2000,
    "tags"          : [
        "Metroid",
        "Samus Aran",
        "Aurahack18",
        "Blonde",
        "blush",
        "sweat",
    ],
    "tags_general"  : [
        "Blonde",
        "blush",
        "sweat",
    ],
    "tags_artist"   : ["Aurahack18"],
    "tags_character": ["Samus Aran"],
    "tags_origin"   : ["Metroid"],
},

{
    "#url"     : "https://thehentaiworld.com/hentai-images/ubel-nt00-sousou-no-frieren/",
    "#class"   : thehentaiworld.ThehentaiworldPostExtractor,
    "#results" : (
        "https://thehentaiworld.com/wp-content/uploads/2024/04/Ubel-nt00-Sousou-no-Frieren-Hentai.jpg",
        "https://thehentaiworld.com/wp-content/uploads/2024/04/Ubel-–-nt00-–-Sousou-no-Frieren-Hentai.jpg",
    ),

    "count"         : 2,
    "num"           : range(1, 2),
    "date"          : "dt:2024-04-16 00:00:00",
    "extension"     : "jpg",
    "file_url"      : "https://thehentaiworld.com/wp-content/uploads/2024/04/Ubel-nt00-Sousou-no-Frieren-Hentai.jpg",
    "filename"      : {
        "Ubel-nt00-Sousou-no-Frieren-Hentai",
        "Ubel-–-nt00-–-Sousou-no-Frieren-Hentai",
    },
    "height"        : 1422,
    "id"            : 226208,
    "score"         : range(3, 5),
    "slug"          : "ubel-nt00-sousou-no-frieren",
    "title"         : "Ubel – nt00 – Sousou no Frieren",
    "type"          : "image",
    "votes"         : range(10, 20),
    "width"         : 800,
    "file_urls"     : [
        "https://thehentaiworld.com/wp-content/uploads/2024/04/Ubel-nt00-Sousou-no-Frieren-Hentai.jpg",
        "https://thehentaiworld.com/wp-content/uploads/2024/04/Ubel-–-nt00-–-Sousou-no-Frieren-Hentai.jpg",
    ],
    "tags"          : [
        "Sousou no Frieren",
        "Ubel",
        "nt00",
        "blush",
        "Green Hair",
        "pubic hair",
        "smile",
    ],
    "tags_general"  : [
        "blush",
        "Green Hair",
        "pubic hair",
        "smile",
    ],
    "tags_artist"   : ["nt00"],
    "tags_character": ["Ubel"],
    "tags_origin"   : ["Sousou no Frieren"],
},

{
    "#url"     : "https://thehentaiworld.com/videos/lucy-heartfilia-and-natsu-dragneel-shiina-ecchi-fairy-tail/#comment-396839",
    "#class"   : thehentaiworld.ThehentaiworldPostExtractor,
    "#results" : "https://thehentaiworld.com/wp-content/uploads/2025/09/Lucy-Heartfilia-and-Natsu-Dragneel-Shiina-Ecchi-Fairy-Tail-Animated-Hentai-Video.mp4",

    "count"         : 1,
    "num"           : 0,
    "date"          : "dt:2025-09-19 00:00:00",
    "extension"     : "mp4",
    "file_url"      : "https://thehentaiworld.com/wp-content/uploads/2025/09/Lucy-Heartfilia-and-Natsu-Dragneel-Shiina-Ecchi-Fairy-Tail-Animated-Hentai-Video.mp4",
    "filename"      : "Lucy-Heartfilia-and-Natsu-Dragneel-Shiina-Ecchi-Fairy-Tail-Animated-Hentai-Video",
    "height"        : 0,
    "id"            : 253263,
    "score"         : 5.0,
    "slug"          : "lucy-heartfilia-and-natsu-dragneel-shiina-ecchi-fairy-tail",
    "title"         : "Lucy Heartfilia and Natsu Dragneel – Shiina Ecchi – Fairy Tail",
    "type"          : "video",
    "votes"         : range(25, 50),
    "width"         : 0,
    "tags"          : [
        "Fairy Tail",
        "Animated",
        "sound",
        "video",
        "lucy heartfilia",
        "Natsu Dragneel",
        "Shiina Ecchi",
        "arse",
        "blush",
        "Cowgirl Ride",
        "cum",
        "cum inside",
        "eye roll",
        "Fingering",
        "Jiggle",
        "legs spread",
        "masturbating",
        "moan",
        "panties",
        "pov",
        "ride",
        "smile",
        "squeeze",
        "vagina",
        "x-ray",
    ],
    "tags_character": [
        "lucy heartfilia",
        "Natsu Dragneel",
    ],
    "tags_general"  : [
        "arse",
        "blush",
        "Cowgirl Ride",
        "cum",
        "cum inside",
        "eye roll",
        "Fingering",
        "Jiggle",
        "legs spread",
        "masturbating",
        "moan",
        "panties",
        "pov",
        "ride",
        "smile",
        "squeeze",
        "vagina",
        "x-ray",
    ],
    "tags_media"    : [
        "Animated",
        "sound",
        "video",
    ],
    "tags_artist"   : ["Shiina Ecchi"],
    "tags_origin"   : ["Fairy Tail"],
},

{
    "#url"     : "https://thehentaiworld.com/3d-cgi-hentai-images/ciri-and-shani-cekc-the-witcher-3/",
    "#class"   : thehentaiworld.ThehentaiworldPostExtractor,
    "#results" : "https://thehentaiworld.com/wp-content/uploads/2025/08/Ciri-and-Shani-CEKC-The-Witcher-3-Hentai-3D-CGI.jpeg",
},

{
    "#url"     : "https://thehentaiworld.com/tag/aurahack/",
    "#class"   : thehentaiworld.ThehentaiworldTagExtractor,
    "#pattern" : r"https://thehentaiworld\.com/wp\-content/uploads/20\d\d/.+",
    "#range"   : "20-",
    "#count"   : 10,

    "count"         : {1, 2},
    "num"           : {1, 2, 0},
    "date"          : "type:datetime",
    "extension"     : {"jpg", "png"},
    "file_url"      : str,
    "filename"      : str,
    "height"        : int,
    "id"            : int,
    "score"         : float,
    "search_tags"   : "aurahack",
    "slug"          : str,
    "tags_artist"   : ["Aurahack18"],
    "title"         : str,
    "type"          : "image",
    "votes"         : int,
    "width"         : int,
    "tags"          : list,
},

)

==> gallery-dl-1.31.1.gh.tar.gz: gallery-dl-1.31.1/test/results/thehentaiworld.py <==
# -*- coding: utf-8 -*-

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.

from gallery_dl.extractor import thehentaiworld


__tests__ = (
{
    "#url"     : "https://thehentaiworld.com/hentai-images/samus-aran-aurahack-metroid-2/",
    "#class"   : thehentaiworld.ThehentaiworldPostExtractor,
    "#results" : "https://thehentaiworld.com/wp-content/uploads/2020/06/Samus-Aran-Aurahack-Metroid-Hentai.jpeg",

    "count"         : 1,
    "num"           : 0,
    "date"          : "dt:2020-06-05 00:00:00",
    "extension"     : "jpeg",
    "file_url"      : "https://thehentaiworld.com/wp-content/uploads/2020/06/Samus-Aran-Aurahack-Metroid-Hentai.jpeg",
    "filename"      : "Samus-Aran-Aurahack-Metroid-Hentai",
    "height"        : 2893,
    "id"            : 147048,
    "score"         : range(3, 5),
    "slug"          : "samus-aran-aurahack-metroid-2",
    "title"         : "Samus Aran – Aurahack – Metroid",
    "type"          : "image",
    "votes"         : range(5, 20),
    "width"         : 2000,
    "tags"          : [
        "Metroid",
        "Samus Aran",
        "Aurahack18",
        "Blonde",
        "blush",
        "sweat",
    ],
    "tags_general"  : [
        "Blonde",
        "blush",
        "sweat",
    ],
    "tags_artist"   : ["Aurahack18"],
    "tags_character": ["Samus Aran"],
    "tags_origin"   : ["Metroid"],
},

{
    "#url"     : "https://thehentaiworld.com/hentai-images/ubel-nt00-sousou-no-frieren/",
    "#class"   : thehentaiworld.ThehentaiworldPostExtractor,
    "#results" : (
        "https://thehentaiworld.com/wp-content/uploads/2024/04/Ubel-nt00-Sousou-no-Frieren-Hentai.jpg",
        "https://thehentaiworld.com/wp-content/uploads/2024/04/Ubel-–-nt00-–-Sousou-no-Frieren-Hentai.jpg",
    ),

    "count"         : 2,
    "num"           : range(1, 2),
    "date"          : "dt:2024-04-16 00:00:00",
    "extension"     : "jpg",
    "file_url"      : "https://thehentaiworld.com/wp-content/uploads/2024/04/Ubel-nt00-Sousou-no-Frieren-Hentai.jpg",
    "filename"      : {
        "Ubel-nt00-Sousou-no-Frieren-Hentai",
        "Ubel-–-nt00-–-Sousou-no-Frieren-Hentai",
    },
    "height"        : 1422,
    "id"            : 226208,
    "score"         : range(3, 5),
    "slug"          : "ubel-nt00-sousou-no-frieren",
    "title"         : "Ubel – nt00 – Sousou no Frieren",
    "type"          : "image",
    "votes"         : range(10, 20),
    "width"         : 800,
    "file_urls"     : [
        "https://thehentaiworld.com/wp-content/uploads/2024/04/Ubel-nt00-Sousou-no-Frieren-Hentai.jpg",
        "https://thehentaiworld.com/wp-content/uploads/2024/04/Ubel-–-nt00-–-Sousou-no-Frieren-Hentai.jpg",
    ],
    "tags"          : [
        "Sousou no Frieren",
        "Ubel",
        "nt00",
        "blush",
        "Green Hair",
        "pubic hair",
        "smile",
    ],
    "tags_general"  : [
        "blush",
        "Green Hair",
        "pubic hair",
        "smile",
    ],
    "tags_artist"   : ["nt00"],
    "tags_character": ["Ubel"],
    "tags_origin"   : ["Sousou no Frieren"],
},

{
    "#url"     : "https://thehentaiworld.com/videos/lucy-heartfilia-and-natsu-dragneel-shiina-ecchi-fairy-tail/#comment-396839",
    "#class"   : thehentaiworld.ThehentaiworldPostExtractor,
    "#results" : "https://thehentaiworld.com/wp-content/uploads/2025/09/Lucy-Heartfilia-and-Natsu-Dragneel-Shiina-Ecchi-Fairy-Tail-Animated-Hentai-Video.mp4",

    "count"         : 1,
    "num"           : 0,
    "date"          : "dt:2025-09-19 00:00:00",
    "extension"     : "mp4",
    "file_url"      : "https://thehentaiworld.com/wp-content/uploads/2025/09/Lucy-Heartfilia-and-Natsu-Dragneel-Shiina-Ecchi-Fairy-Tail-Animated-Hentai-Video.mp4",
    "filename"      : "Lucy-Heartfilia-and-Natsu-Dragneel-Shiina-Ecchi-Fairy-Tail-Animated-Hentai-Video",
    "height"        : 0,
    "id"            : 253263,
    "score"         : 5.0,
    "slug"          : "lucy-heartfilia-and-natsu-dragneel-shiina-ecchi-fairy-tail",
    "title"         : "Lucy Heartfilia and Natsu Dragneel – Shiina Ecchi – Fairy Tail",
    "type"          : "video",
    "votes"         : range(25, 50),
    "width"         : 0,
    "tags"          : [
        "Fairy Tail",
        "Animated",
        "sound",
        "video",
        "lucy heartfilia",
        "Natsu Dragneel",
        "Shiina Ecchi",
        "arse",
        "blush",
        "Cowgirl Ride",
        "cum",
        "cum inside",
        "eye roll",
        "Fingering",
        "Jiggle",
        "legs spread",
        "masturbating",
        "moan",
        "panties",
        "pov",
        "ride",
        "smile",
        "squeeze",
        "vagina",
        "x-ray",
    ],
    "tags_character": [
        "lucy heartfilia",
        "Natsu Dragneel",
    ],
    "tags_general"  : [
        "arse",
        "blush",
        "Cowgirl Ride",
        "cum",
        "cum inside",
        "eye roll",
        "Fingering",
        "Jiggle",
        "legs spread",
        "masturbating",
        "moan",
        "panties",
        "pov",
        "ride",
        "smile",
        "squeeze",
        "vagina",
        "x-ray",
    ],
    "tags_media"    : [
        "Animated",
        "sound",
        "video",
    ],
    "tags_artist"   : ["Shiina Ecchi"],
    "tags_origin"   : ["Fairy Tail"],
},

{
    "#url"     : "https://thehentaiworld.com/3d-cgi-hentai-images/ciri-and-shani-cekc-the-witcher-3/",
    "#class"   : thehentaiworld.ThehentaiworldPostExtractor,
    "#results" : "https://thehentaiworld.com/wp-content/uploads/2025/08/Ciri-and-Shani-CEKC-The-Witcher-3-Hentai-3D-CGI.jpeg",

    "type"     : "3d cgi",
},

{
    "#url"     : "https://thehentaiworld.com/gif-animated-hentai-images/rangiku-matsumoto-sketchdrif-bleach/",
    "#class"   : thehentaiworld.ThehentaiworldPostExtractor,
    "#results" : "https://thehentaiworld.com/wp-content/uploads/2025/05/Rangiku-Matsumoto-Sketchdrif-Bleach-Animated-Hentai.gif",

    "type"     : "animated",
},

{
    "#url"     : "https://thehentaiworld.com/tag/aurahack/",
    "#class"   : thehentaiworld.ThehentaiworldTagExtractor,
    "#pattern" : r"https://thehentaiworld\.com/wp\-content/uploads/20\d\d/.+",
    "#range"   : "20-",
    "#count"   : 10,

    "count"         : {1, 2},
    "num"           : {1, 2, 0},
    "date"          : "type:datetime",
    "extension"     : {"jpg", "png"},
    "file_url"      : str,
    "filename"      : str,
    "height"        : int,
    "id"            : int,
    "score"         : float,
    "search_tags"   : "aurahack",
    "slug"          : str,
    "tags_artist"   : ["Aurahack18"],
    "title"         : str,
    "type"          : "image",
    "votes"         : int,
    "width"         : int,
    "tags"          : list,
},

)
